@@ -30,3 +30,7 @@ class Geocoordinates:
 
     def to_dict(self, lat="lat", lng="lng") -> dict:
         return {lat: self.lat, lng: self.lng}
+
+    def __str__(self):
+        lat_direction, lng_direction = "N" if self.lat >= 0 else "S", "E" if self.lng >= 0 else "W"
+        return f"{round(abs(self.lat), 8)}\u00B0 {lat_direction}, {round(abs(self.lng), 8)}\u00B0 {lng_direction}"
