@@ -1,5 +1,4 @@
 import unittest
-
 import gloc
 from gloc import Location, Geocoordinates
 import mock_data
@@ -7,6 +6,21 @@ import mock_data
 
 class TestLocation(unittest.TestCase):
 
+    def test_address_param(self):
+        self.assertEqual(
+            "Skånegatan%2059,%20412%2052%20Göteborg,%20Sweden",
+            gloc._create_address_param("Skånegatan 59, 412 52 Göteborg, Sweden")
+        )
+
+    def test_create_address_string(self):
+        self.assertEqual(
+            "Skånegatan 59, 412 52 Göteborg, Sweden",
+            gloc.create_address_string("Skånegatan 59", "412 52", "Göteborg", "Sweden")
+        )
+
+    def test_invalid_api_key(self):
+        self.assertRaises(IOError, Location.from_address, "some_address", "an_invalid_api_key")
+
     def test_constructors(self):
         l1 = Location(**gloc._parse(mock_data.GÖTAPLATSEN_FROM_ADDRESS))
         l2 = Location(**gloc._parse(mock_data.GÖTAPLATSEN_FROM_COORDINATES))
